@@ -3,27 +3,36 @@ Testcases for NSArchive-ing python objects.
 
 (Implementation is incomplete)
 """
-import os
-
-import sys
 import pickle
+import sys
+import test.pickletester
 
-if sys.version_info[0] == 3:
-    import copyreg
-
-    long = int
-
-else:
-    import copy_reg as copyreg
-
-from PyObjCTools.TestSupport import *
+import objc
 import objc._pycoder as pycoder
+from PyObjCTest.fnd import (
+    NSArchiver,
+    NSArray,
+    NSData,
+    NSDictionary,
+    NSKeyedArchiver,
+    NSKeyedUnarchiver,
+    NSMutableArray,
+    NSMutableData,
+    NSMutableDictionary,
+    NSSet,
+    NSString,
+    NSUnarchiver,
+)
+from PyObjCTools.TestSupport import (
+    TestCase,
+    onlyIf,
+    expectedFailure,
+    expectedFailureIf,
+    os_level_key,
+    os_release,
+)
 
-from PyObjCTest.fnd import NSArchiver, NSUnarchiver
-from PyObjCTest.fnd import NSKeyedArchiver, NSKeyedUnarchiver
-from PyObjCTest.fnd import NSData, NSArray, NSDictionary
-from PyObjCTest.fnd import NSMutableArray, NSMutableDictionary
-from PyObjCTest.fnd import NSMutableData, NSString, NSSet
+import copyreg
 
 #
 # First set of tests: the stdlib tests for pickling, this
@@ -31,12 +40,6 @@ from PyObjCTest.fnd import NSMutableData, NSString, NSSet
 # object-graphs.
 #
 
-if sys.version_info[0] == 3:
-    unicode = str
-    long = int
-
-import test.pickletester
-
 MyList = test.pickletester.MyList
 
 
@@ -99,10 +102,15 @@ class reduce_global(object):
 
 reduce_global = reduce_global()
 
-# Quick hack to add a proper __repr__ to class C in
-# pickletester, makes it a lot easier to debug.
+
 def C__repr__(self):
-    return "<%s instance at %#x: %r>" % (self.__class__.__name__, id(self), self.__dict__)
+    # Quick hack to add a proper __repr__ to class C in
+    # pickletester, makes it a lot easier to debug.
+    return "<%s instance at %#x: %r>" % (
+        self.__class__.__name__,
+        id(self),
+        self.__dict__,
+    )
 
 
 test.pickletester.C.__repr__ = C__repr__
@@ -267,7 +275,7 @@ class TestKeyedArchiveSimple(TestCase):
                 archiver.finishEncoding()
 
         finally:
-            mystr = orig
+            mystr = orig  # noqa: F841
 
         try:
             copyreg.add_extension(
@@ -304,7 +312,6 @@ class TestKeyedArchiveSimple(TestCase):
             )
 
         finally:
-            mystr = orig
             try:
                 copyreg.remove_extension(
                     a_newstyle_class.__module__, a_newstyle_class.__name__, 42
@@ -329,22 +336,6 @@ class TestKeyedArchiveSimple(TestCase):
         finally:
             del f
 
-    @onlyPython2
-    def test_invalid_initargs(self):
-        v = myobject()
-        buf = self.archiverClass.archivedDataWithRootObject_(v)
-        self.assertIsInstance(buf, NSData)
-
-        if os_level_key(os_release()) >= os_level_key("10.9"):
-            # On OSX 10.11 (un)archivers modify exceptions, which looses
-            # enough information that PyObjC can no longer reconstruct
-            # the correct Python exception
-            exception = (objc.error, TypeError)
-        else:
-            exception = objc.error
-
-        self.assertRaises(exception, self.unarchiverClass.unarchiveObjectWithData_, buf)
-
     def test_class_with_slots(self):
         # Test dumpling a class with slots
         o = newstyle_with_slots()
@@ -360,17 +351,6 @@ class TestKeyedArchiveSimple(TestCase):
         self.assertEqual(v.b, 2)
         self.assertEqual(v.c, 3)
 
-    @onlyPython2
-    def test_class_with_state(self):
-        o = state_obj_1()
-        buf = self.archiverClass.archivedDataWithRootObject_(o)
-        self.assertIsInstance(buf, NSData)
-        v = self.unarchiverClass.unarchiveObjectWithData_(buf)
-        self.assertIsInstance(v, state_obj_1)
-        self.assertEqual(v.a, 1)
-        self.assertEqual(v.b, 2)
-        self.assertEqual(v.__dict__[42], 3)
-
     def test_class_with_setstate(self):
         o = newstyle_with_setstate()
         o.a = 1
@@ -502,23 +482,17 @@ class TestKeyedArchiveSimple(TestCase):
         buf = self.archiverClass.archivedDataWithRootObject_(o)
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
-        if sys.version_info[0] == 2 and not self.isKeyed:
-            self.assertIsInstance(v, unicode)
-        else:
-            self.assertIsInstance(v, str)
+        self.assertIsInstance(v, str)
         self.assertEqual(o, v)
 
         o = b"hello world"
         buf = self.archiverClass.archivedDataWithRootObject_(o)
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
-        self.assertIsInstance(
-            v,
-            bytes if self.isKeyed else (NSData if sys.version_info[0] == 3 else unicode),
-        )
+        self.assertIsInstance(v, bytes if self.isKeyed else NSData)
         self.assertEqual(o, v)
 
-        o = b"hello world".decode("ascii")
+        o = "hello world"
         buf = self.archiverClass.archivedDataWithRootObject_(o)
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
@@ -546,30 +520,22 @@ class TestKeyedArchiveSimple(TestCase):
         self.assertIsInstance(v, float)
         self.assertEqual(o, v)
 
-        if sys.version_info[0] == 2:
-            buf = self.archiverClass.archivedDataWithRootObject_(unicode("hello"))
-            self.assertIsInstance(buf, NSData)
-            v = self.unarchiverClass.unarchiveObjectWithData_(buf)
-            self.assertIsInstance(v, unicode)
-
         buf = self.archiverClass.archivedDataWithRootObject_("hello")
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
-        self.assertIsInstance(
-            v, str if sys.version_info[0] == 3 or self.isKeyed else unicode
-        )
+        self.assertIsInstance(v, str)
         self.assertEqual(v, "hello")
 
         buf = self.archiverClass.archivedDataWithRootObject_(sys.maxsize * 4)
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
-        self.assertIsInstance(v, long)
+        self.assertIsInstance(v, int)
         self.assertEqual(v, sys.maxsize * 4)
 
         buf = self.archiverClass.archivedDataWithRootObject_(sys.maxsize ** 4)
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
-        self.assertIsInstance(v, long)
+        self.assertIsInstance(v, int)
         self.assertEqual(v, sys.maxsize ** 4)
 
     def testSimpleLists(self):
@@ -584,7 +550,7 @@ class TestKeyedArchiveSimple(TestCase):
             self.assertIsInstance(v, NSMutableArray)
             self.assertEqual(list(v), o)
 
-        o = [unicode("hello"), 42]
+        o = ["hello", 42]
         buf = self.archiverClass.archivedDataWithRootObject_(o)
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
@@ -603,7 +569,7 @@ class TestKeyedArchiveSimple(TestCase):
         self.assertIsInstance(v, list_subclass)
         self.assertEqual(v, o)
 
-        o = list_subclass([unicode("hello"), 42])
+        o = list_subclass(["hello", 42])
         buf = self.archiverClass.archivedDataWithRootObject_(o)
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
@@ -622,7 +588,7 @@ class TestKeyedArchiveSimple(TestCase):
             self.assertIsInstance(v, NSArray)
             self.assertEqual(tuple(v), o)
 
-        o = (unicode("hello"), 42)
+        o = ("hello", 42)
         buf = self.archiverClass.archivedDataWithRootObject_(o)
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
@@ -643,7 +609,7 @@ class TestKeyedArchiveSimple(TestCase):
         self.assertEqual(v, o)
         self.assertEqual(v.a, o.a)
 
-        o = tuple_subclass([unicode("hello"), 42])
+        o = tuple_subclass(["hello", 42])
         o.a = 99
         buf = self.archiverClass.archivedDataWithRootObject_(o)
         self.assertIsInstance(buf, NSData)
@@ -660,7 +626,7 @@ class TestKeyedArchiveSimple(TestCase):
         self.assertIsInstance(v, dict if self.isKeyed else NSDictionary)
         self.assertEqual(dict(v), o)
 
-        o = {unicode("hello"): unicode("bar"), 42: 1.5}
+        o = {"hello": "bar", 42: 1.5}
         buf = self.archiverClass.archivedDataWithRootObject_(o)
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
@@ -677,7 +643,7 @@ class TestKeyedArchiveSimple(TestCase):
         self.assertEqual(v, o)
         self.assertEqual(v.a, o.a)
 
-        o = dict_subclass({unicode("hello"): unicode("bar"), 42: 1.5})
+        o = dict_subclass({"hello": "bar", 42: 1.5})
         o.a = 99
         buf = self.archiverClass.archivedDataWithRootObject_(o)
         self.assertIsInstance(buf, NSData)
@@ -687,7 +653,7 @@ class TestKeyedArchiveSimple(TestCase):
         self.assertEqual(v.a, o.a)
 
     def testNestedDicts(self):
-        o = {unicode("hello"): {1: 2}, unicode("world"): unicode("foobar")}
+        o = {"hello": {1: 2}, "world": "foobar"}
         buf = self.archiverClass.archivedDataWithRootObject_(o)
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
@@ -695,21 +661,21 @@ class TestKeyedArchiveSimple(TestCase):
         self.assertEqual(v, o)
 
         o = {}
-        o[unicode("self")] = o
+        o["self"] = o
         buf = self.archiverClass.archivedDataWithRootObject_(o)
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
         self.assertIsInstance(v, dict if self.isKeyed else NSMutableDictionary)
 
         if self.isKeyed:
-            self.assertIs(v[unicode("self")], v)
+            self.assertIs(v["self"], v)
 
         else:
             # See 'TestArchiveNative'
-            self.assertIsNot(v[unicode("self")], v)
+            self.assertIsNot(v["self"], v)
 
     def testNestedSequences(self):
-        o = [1, 2, 3, (5, (unicode("a"), unicode("b")), 6), {1: 2}]
+        o = [1, 2, 3, (5, ("a", "b"), 6), {1: 2}]
         o[-1] = o
 
         buf = self.archiverClass.archivedDataWithRootObject_(o)
@@ -747,7 +713,7 @@ class TestKeyedArchiveSimple(TestCase):
         import pickle
 
         b = pickle.dumps(o)
-        o2 = pickle.loads(b)
+        pickle.loads(b)
 
         buf = self.archiverClass.archivedDataWithRootObject_(o)
         self.assertIsInstance(buf, NSData)
@@ -766,13 +732,13 @@ class TestKeyedArchiveSimple(TestCase):
         self.assertEqual(o.value, 42)
 
     def testRecusiveNesting(self):
-        l = []
-        d = {1: l}
+        lst = []
+        d = {1: lst}
         i = a_classic_class()
         i.attr = d
-        l.append(i)
+        lst.append(i)
 
-        buf = self.archiverClass.archivedDataWithRootObject_(l)
+        buf = self.archiverClass.archivedDataWithRootObject_(lst)
         self.assertIsInstance(buf, NSData)
         v = self.unarchiverClass.unarchiveObjectWithData_(buf)
 
@@ -1099,21 +1065,32 @@ class TestKeyedArchivePlainPython(TestCase, test.pickletester.AbstractPickleTest
     def test_recursive_set_and_inst(self):
         test.pickletester.AbstractPickleTests.test_recursive_set_and_inst(self)
 
+    @expectedFailure
+    def test_recursive_set(self):
+        # XXX: Need further investigation
+        test.pickletester.AbstractPickleTests.test_recursive_set(self)
+
     @expectedFailure
     def test_recursive_frozenset_and_inst(self):
         test.pickletester.AbstractPickleTests.test_recursive_frozenset_and_inst(self)
 
     @expectedFailure
     def test_recursive_list_subclass_and_inst(self):
-        test.pickletester.AbstractPickleTests.test_recursive_list_subclass_and_inst(self)
+        test.pickletester.AbstractPickleTests.test_recursive_list_subclass_and_inst(
+            self
+        )
 
     @expectedFailure
     def test_recursive_tuple_subclass_and_inst(self):
-        test.pickletester.AbstractPickleTests.test_recursive_tuple_subclass_and_inst(self)
+        test.pickletester.AbstractPickleTests.test_recursive_tuple_subclass_and_inst(
+            self
+        )
 
     @expectedFailure
     def test_recursive_dict_subclass_and_inst(self):
-        test.pickletester.AbstractPickleTests.test_recursive_dict_subclass_and_inst(self)
+        test.pickletester.AbstractPickleTests.test_recursive_dict_subclass_and_inst(
+            self
+        )
 
     @expectedFailure
     def test_recursive_set_subclass_and_inst(self):
@@ -1139,7 +1116,7 @@ class TestKeyedArchivePlainPython(TestCase, test.pickletester.AbstractPickleTest
 
         self.assertEqual(v, x)
 
-        for val in (long(0), long(1), long(sys.maxsize), long(sys.maxsize * 128)):
+        for val in (int(0), int(1), int(sys.maxsize), int(sys.maxsize * 128)):
             for x in val, -val:
                 buf = self.dumps(x)
                 v = self.loads(buf)
@@ -1227,21 +1204,79 @@ class TestArchivePlainPython(TestKeyedArchivePlainPython):
     def loads(self, buf):
         return NSUnarchiver.unarchiveObjectWithData_(buf)
 
+    @expectedFailure
+    def test_recursive_dict_like_key(self):
+        # XXX: Needs further investigation...
+        test.pickletester.AbstractPickleTests.test_recursive_dict_like_key(self)
+
+    @expectedFailure
+    def test_recursive_tuple_and_dict_key(self):
+        # XXX: Needs further investigation...
+        test.pickletester.AbstractPickleTests.test_recursive_tuple_and_dict_key(self)
+
+    @expectedFailure
+    def test_recursive_tuple_and_dict_like_key(self):
+        # XXX: Needs further investigation...
+        test.pickletester.AbstractPickleTests.test_recursive_tuple_and_dict_like_key(
+            self
+        )
+
+    @expectedFailure
+    def test_recursive_tuple_and_dict_subclass_key(self):
+        # XXX: Needs further investigation...
+        test.pickletester.AbstractPickleTests.test_recursive_tuple_and_dict_subclass_key(
+            self
+        )
+
+    @expectedFailure
+    def test_recursive_tuple_and_inst_state(self):
+        # XXX: Needs further investigation...
+        test.pickletester.AbstractPickleTests.test_recursive_tuple_and_inst_state(self)
+
+    @expectedFailure
+    def test_recursive_tuple_and_dict(self):
+        # XXX: Needs further investigation...
+        test.pickletester.AbstractPickleTests.test_recursive_tuple_and_dict(self)
+
+    @expectedFailure
+    def test_recursive_tuple_and_dict_subclass(self):
+        # XXX: Needs further investigation...
+        test.pickletester.AbstractPickleTests.test_recursive_tuple_and_dict_subclass(
+            self
+        )
+
+    @expectedFailure
+    def test_recursive_tuple_and_list_like(self):
+        # XXX: Needs further investigation...
+        test.pickletester.AbstractPickleTests.test_recursive_tuple_and_list_like(self)
+
+    @expectedFailure
+    def test_recursive_tuple_and_list_subclass(self):
+        # XXX: Needs further investigation...
+        test.pickletester.AbstractPickleTests.test_recursive_tuple_and_list_subclass(
+            self
+        )
+
+    @expectedFailure
+    def test_recursive_set(self):
+        # XXX: Needs further investigation...
+        test.pickletester.AbstractPickleTests.test_recursive_set(self)
+
     @expectedFailure
     def test_recursive_dict(self):
         # See 'TestArchiveNative'
         test.pickletester.AbstractPickleTests.test_recursive_dict(self)
 
+    @expectedFailure
+    def test_recursive_tuple_and_dict_like(self):
+        # See 'TestArchiveNative'
+        test.pickletester.AbstractPickleTests.test_recursive_tuple_and_dict_like(self)
+
     @expectedFailure
     def test_recursive_dict_key(self):
         # See 'TestArchiveNative'
         test.pickletester.AbstractPickleTests.test_recursive_dict_key(self)
 
-    @expectedFailure
-    def test_recursive_set(self):
-        # See 'TestArchiveNative'
-        test.pickletester.AbstractPickleTests.test_recursive_set(self)
-
     @expectedFailure
     def test_recursive_frozenset(self):
         # See 'TestArchiveNative'
@@ -1363,15 +1398,21 @@ class TestArchivePlainPython(TestKeyedArchivePlainPython):
 
     @expectedFailure
     def test_recursive_list_subclass_and_inst(self):
-        test.pickletester.AbstractPickleTests.test_recursive_list_subclass_and_inst(self)
+        test.pickletester.AbstractPickleTests.test_recursive_list_subclass_and_inst(
+            self
+        )
 
     @expectedFailure
     def test_recursive_tuple_subclass_and_inst(self):
-        test.pickletester.AbstractPickleTests.test_recursive_tuple_subclass_and_inst(self)
+        test.pickletester.AbstractPickleTests.test_recursive_tuple_subclass_and_inst(
+            self
+        )
 
     @expectedFailure
     def test_recursive_dict_subclass_and_inst(self):
-        test.pickletester.AbstractPickleTests.test_recursive_dict_subclass_and_inst(self)
+        test.pickletester.AbstractPickleTests.test_recursive_dict_subclass_and_inst(
+            self
+        )
 
     @expectedFailure
     def test_recursive_set_subclass_and_inst(self):
@@ -1416,9 +1457,9 @@ class TestKeyedArchiveMixedGraphs(TestCase):
         o1 = a_classic_class()
         o2 = a_newstyle_class()
         o2.lst = NSArray.arrayWithObject_(o1)
-        l = NSArray.arrayWithArray_([o1, o2, [o1, o2]])
+        lst = NSArray.arrayWithArray_([o1, o2, [o1, o2]])
 
-        buf = self.dumps(l)
+        buf = self.dumps(lst)
         self.assertIsInstance(buf, NSData)
 
         out = self.loads(buf)
@@ -1502,7 +1543,7 @@ class TestArchiveNative(TestCase):
         self.assertIsInstance(buf, NSData)
         b = self.loads(buf)
         self.assertEqual(a, b)
-        self.assertIsInstance(b, (int, long))
+        self.assertIsInstance(b, int)
 
         a = 1.5
         buf = self.dumps(a)
@@ -1536,7 +1577,7 @@ class TestArchiveNative(TestCase):
         b = self.loads(buf)
         self.assertIsInstance(b, with_getstate)
         self.assertEqual(a.value, b.value)
-        self.assertIsInstance(b.value, (int, long))
+        self.assertIsInstance(b.value, int)
 
         a = with_getstate(1 << 100)
         self.assertEqual(a.value, 1 << 100)
@@ -1545,7 +1586,7 @@ class TestArchiveNative(TestCase):
         b = self.loads(buf)
         self.assertIsInstance(b, with_getstate)
         self.assertEqual(a.value, b.value)
-        self.assertIsInstance(b.value, (int, long))
+        self.assertIsInstance(b.value, int)
 
         a = with_getstate((1, 2))
         self.assertEqual(a.value, (1, 2))
@@ -1566,22 +1607,11 @@ class TestArchiveNative(TestCase):
         self.assertIsInstance(b, only_getstate)
         self.assertEqual(
             b.__dict__,
-            {
-                #'_slots': None,
-                #'_kwds': None,
-                "a": 42,
-                "b": 9,
-                "c": 4,
-                "d": 7,
-                42: "b",
-                "nsstr": "xx",
-                "otherstr": "b",
-            },
+            {"a": 42, "b": 9, "c": 4, "d": 7, 42: "b", "nsstr": "xx", "otherstr": "b"},
         )
         for k in b.__dict__:
             self.assertNotIsInstance(k, objc.pyobjc_unicode)
-            if sys.version_info[0] == 3:
-                self.assertNotIsInstance(k, bytes)
+            self.assertNotIsInstance(k, bytes)
 
         a = with_reduce_func([1, 2], (3, 4), {"a": 4}, {"d", "e"}, frozenset(["f"]), id)
         buf = self.dumps(a)
@@ -1611,7 +1641,3 @@ class TestKeyedArchiveNative(TestArchiveNative):
 #
 class TestArchivePythonObjCSubclass(TestCase):
     pass
-
-
-if __name__ == "__main__":
-    main()
