@@ -1,16 +1,19 @@
 import objc
 import objc._objc
 from objc._protocols import PROTOCOL_CACHE
-from PyObjCTools.TestSupport import *
+from PyObjCTools.TestSupport import TestCase
 
-class TestProtocols (TestCase):
+
+class TestProtocols(TestCase):
     def testBasic(self):
         PROTOCOL_CACHE.clear()
-        p = objc.protocolNamed('NSObject')
+        p = objc.protocolNamed("NSObject")
         self.assertIsInstance(p, objc.formal_protocol)
 
     def testNoProtocol(self):
-        self.assertRaises(objc.ProtocolError, objc.protocolNamed, "PyObjCFooBarProtocol")
+        self.assertRaises(
+            objc.ProtocolError, objc.protocolNamed, "PyObjCFooBarProtocol"
+        )
 
     def testBasic2(self):
         orig_protocolsForProcess = objc._objc.protocolsForProcess
@@ -18,11 +21,8 @@ class TestProtocols (TestCase):
             objc._objc.protocolsForProcess = lambda: []
             PROTOCOL_CACHE.clear()
 
-            p = objc.protocolNamed('NSObject')
+            p = objc.protocolNamed("NSObject")
             self.assertIsInstance(p, objc.formal_protocol)
 
         finally:
             objc._objc.protocolsForProcess = orig_protocolsForProcess
-
-if __name__ == "__main__":
-    main()
